@@ -1,7 +1,9 @@
 package DateTime::LeapSecond;
 
-use 5.005;
 use strict;
+use warnings;
+
+our $VERSION = '0.52';
 
 use vars qw( $VERSION );
 use vars qw( @RD @LEAP_SECONDS %RD_LENGTH );
@@ -134,7 +136,7 @@ This module is used to calculate leap seconds for a given Rata Die
 day.  It is used when DateTime.pm cannot compile the XS version of
 this code.
 
-This library is known to be accurate for dates until december 2005.
+This library is known to be accurate for dates until December 2009.
 
 There are no leap seconds before 1972, because that's the year this
 system was implemented.
@@ -164,7 +166,7 @@ Flvio Soibelmann Glock, E<lt>fglock@pucrs.brE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003 Flvio Soibelmann Glock.  Copyright (c) 2004-2006
+Copyright (c) 2003 Flvio Soibelmann Glock.  Copyright (c) 2004-2009
 David Rolsky.  All rights reserved.  This program is free software;
 you can redistribute it and/or modify it under the same terms as Perl
 itself.
